==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/fi.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ladataan esikatselua…",
    "Saved" : "Tallennettu",
    "Admin" : "Ylläpito",
    "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
    "Name cannot be empty" : "Nimi ei voi olla tyhjä",
    "The given name is too long" : "Nimi on liian pitkä",
    "The given web address is too long" : "Verkko-osoite on liian pitkä",
    "The given legal notice address is too long" : "Annettu lainopillisen huomautuksen osoite on liian pitkä",
    "The given privacy policy address is too long" : "Annettu yksityiskäytännön osoite on liian pitkä",
    "The given slogan is too long" : "Slogani on liian pitkä",
    "The given color is invalid" : "Väri on virheellinen",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lähetetty tiedosto ylittää php.ini-tiedoston upload_max_filesize-tietueen arvon",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Tiedostoa ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähettämisen",
    "No file uploaded" : "Ei tiedostoa lähetetty",
    "Unsupported image type" : "Ei-tuettu kuvatiedostomuoto",
    "Legal notice" : "Lainopillinen huomautus",
    "Privacy policy" : "Yksityisyyskäytäntö",
    "Theming" : "Teema",
    "Adjust the Nextcloud theme" : "Mukauta Nextcloudin teemaa",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teeman avulla voit helposti kustomoida web-käyttöliittymän ja tuettujen sovelluksien ulkonäköä ja tuntumaa. Teema näkyy kaikille käyttäjille.",
    "Name" : "Nimi",
    "Reset to default" : "Palauta oletukseksi",
    "Web link" : "Verkkolinkki",
    "https://…" : "https://…",
    "Slogan" : "Slogani",
    "Color" : "Väri",
    "Logo" : "Logo",
    "Upload new logo" : "Lähetä uusi logo",
    "Login image" : "Kirjautumissivun kuva",
    "Upload new login background" : "Lähetä uusi kirjautumissivun taustakuva",
    "Remove background image" : "Poista taustakuva",
    "Advanced options" : "Lisävalinnat",
    "Legal notice link" : "Lainopillisen huomautuksen linkki",
    "Privacy policy link" : "Yksityisyyskäytännön linkki",
    "Header logo" : "Otsakelogo",
    "Upload new header logo" : "Lähetä uusi otsakelogo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Lähetä uusi favicon",
    "There is no error, the file uploaded with success" : "Ei virhettä, tiedosto lähetettiin onnistuneesti",
    "The uploaded file was only partially uploaded" : "Lähetetty tiedosto lähetettiin vain osittain",
    "Failed to write file to disk." : "Levylle kirjoittaminen epäonnistui.",
    "A PHP extension stopped the file upload." : "PHP-laajennus pysäytti tiedoston lähetyksen.",
    "You are already using a custom theme" : "Käytät jo kustomoitua ulkoasua",
    "Web address https://…" : "Verkko-osoite https://…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/fi.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ladataan esikatselua…",
    "Saved" : "Tallennettu",
    "Admin" : "Ylläpito",
    "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
    "Name cannot be empty" : "Nimi ei voi olla tyhjä",
    "The given name is too long" : "Nimi on liian pitkä",
    "The given web address is too long" : "Verkko-osoite on liian pitkä",
    "The given web address is not a valid URL" : "Annettu verkko-osoite ei ole kelvollinen URL",
    "The given legal notice address is too long" : "Annettu lainopillisen huomautuksen osoite on liian pitkä",
    "The given legal notice address is not a valid URL" : "Annettu lainopillisen huomautuksen osoite ei ole kelvollinen URL",
    "The given privacy policy address is too long" : "Annettu yksityiskäytännön osoite on liian pitkä",
    "The given privacy policy address is not a valid URL" : "Annettu yksityiskäytännön osoite ei ole kelvollinen URL",
    "The given slogan is too long" : "Slogani on liian pitkä",
    "The given color is invalid" : "Väri on virheellinen",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lähetetty tiedosto ylittää php.ini-tiedoston upload_max_filesize-tietueen arvon",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Tiedostoa ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähettämisen",
    "No file uploaded" : "Ei tiedostoa lähetetty",
    "Unsupported image type" : "Ei-tuettu kuvatiedostomuoto",
    "Theming" : "Teema",
    "Legal notice" : "Lainopillinen huomautus",
    "Privacy policy" : "Yksityisyyskäytäntö",
    "Adjust the Nextcloud theme" : "Mukauta Nextcloudin teemaa",
    "Open documentation" : "Avaa dokumentaatio",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teeman avulla voit helposti kustomoida web-käyttöliittymän ja tuettujen sovelluksien ulkonäköä ja tuntumaa. Teema näkyy kaikille käyttäjille.",
    "Name" : "Nimi",
    "Reset to default" : "Palauta oletukseksi",
    "Web link" : "Verkkolinkki",
    "https://…" : "https://…",
    "Slogan" : "Slogani",
    "Color" : "Väri",
    "Logo" : "Logo",
    "Upload new logo" : "Lähetä uusi logo",
    "Login image" : "Kirjautumissivun kuva",
    "Upload new login background" : "Lähetä uusi kirjautumissivun taustakuva",
    "Remove background image" : "Poista taustakuva",
    "Advanced options" : "Lisävalinnat",
    "Legal notice link" : "Lainopillisen huomautuksen linkki",
    "Privacy policy link" : "Yksityisyyskäytännön linkki",
    "Header logo" : "Otsakelogo",
    "Upload new header logo" : "Lähetä uusi otsakelogo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Lähetä uusi favicon"
},
"nplurals=2; plural=(n != 1);");
